Index: Source/modules/presentation/PresentationController.h |
diff --git a/Source/modules/presentation/PresentationController.h b/Source/modules/presentation/PresentationController.h |
index ad2aae3386e3239ccdf4e660fdaad53430e39970..38c1cf6bdee79fb4a0b8f48dc5b2e41ce1dffd9c 100644 |
--- a/Source/modules/presentation/PresentationController.h |
+++ b/Source/modules/presentation/PresentationController.h |
@@ -5,7 +5,7 @@ |
#ifndef PresentationController_h |
#define PresentationController_h |
-#include "core/frame/FrameDestructionObserver.h" |
+#include "core/frame/LocalFrameLifecycleObserver.h" |
#include "modules/presentation/Presentation.h" |
#include "platform/Supplementable.h" |
#include "platform/heap/Handle.h" |
@@ -22,7 +22,7 @@ class WebPresentationSessionClient; |
class PresentationController final |
: public NoBaseWillBeGarbageCollectedFinalized<PresentationController> |
, public WillBeHeapSupplement<LocalFrame> |
- , public FrameDestructionObserver |
+ , public LocalFrameLifecycleObserver |
, public WebPresentationController { |
WILL_BE_USING_GARBAGE_COLLECTED_MIXIN(PresentationController); |
WTF_MAKE_NONCOPYABLE(PresentationController); |
@@ -63,7 +63,7 @@ public: |
private: |
PresentationController(LocalFrame&, WebPresentationClient*); |
// Implementation of FrameDestructionObserver. |
virtual void willDetachFrameHost() override; |
WebPresentationClient* m_client; |
@@ -63,7 +63,7 @@ public: |
private: |
PresentationController(LocalFrame&, WebPresentationClient*); |
- // Implementation of FrameDestructionObserver. |
+ // Implementation of LocalFrameLifecycleObserver. |
virtual void willDetachFrameHost() override; |
WebPresentationClient* m_client; |